@@ -1,8 +1,8 @@
 import pytest
 import requests_mock
-from meiga.assertions import assert_failure, assert_success
+from meiga.assertions import assert_success
 
-from petisco import ConnectionRequestError, Response
+from petisco.webhooks.webhook.domain.webhook_result import WebhookResult
 from tests.modules.webook.mothers.webhook_mother import WebhookMother, DEFAULT_POST_URL
 from tests.modules.webook.mothers.webhook_sender_mother import WebhookSenderMother
 
@@ -13,7 +13,11 @@ def test_should_be_failure_when_ping_a_webhook_and_url_is_not_reachable():
     sender = WebhookSenderMother.default()
 
     result = sender.ping(webhook)
-    assert_failure(result, value_is_instance_of=ConnectionRequestError)
+
+    assert_success(result, value_is_instance_of=WebhookResult)
+
+    webhook_result = result.value
+    assert not webhook_result.is_success
 
 
 @pytest.mark.integration
@@ -23,7 +27,10 @@ def test_should_be_failure_when_execute_a_webhook_and_url_is_not_reachable():
 
     result = sender.execute(webhook, {"payload": "ok"})
 
-    assert_failure(result, value_is_instance_of=ConnectionRequestError)
+    assert_success(result, value_is_instance_of=WebhookResult)
+
+    webhook_result = result.value
+    assert not webhook_result.is_success
 
 
 @pytest.mark.integration
@@ -34,7 +41,8 @@ def test_should_be_success_when_ping_a_webhook_and_url_is_reachable_by_mocking_i
     with requests_mock.Mocker() as m:
         m.post(DEFAULT_POST_URL)
         result = sender.ping(webhook)
-        assert_success(result, value_is_instance_of=Response)
+        webhook_result = result.value
+        assert webhook_result.is_success
 
 
 @pytest.mark.integration
@@ -45,4 +53,5 @@ def test_should_be_success_when_execute_a_webhook_and_url_is_reachable_by_mockin
     with requests_mock.Mocker() as m:
         m.post(DEFAULT_POST_URL)
         result = sender.execute(webhook, {"payload": "ok"})
-        assert_success(result, value_is_instance_of=Response)
+        webhook_result = result.value
+        assert webhook_result.is_success
